@@ -1,19 +1,22 @@
 package org.apache.velocity.anakia;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
 import org.jdom.Element;
@@ -28,23 +31,33 @@ import java.util.List;
  * same way as a single-element {@link NodeList} would.
  *
  * @author <a href="mailto:szegedia@freemail.hu">Attila Szegedi</a>
- * @version $Id: AnakiaElement.java,v 1.3.4.1 2004/03/03 23:22:03 geirm Exp $
+ * @version $Id: AnakiaElement.java 463298 2006-10-12 16:10:32Z henning $
  */
 public class AnakiaElement extends Element
 {
+    /**
+     * Version Id for serializable
+     */
+    private static final long serialVersionUID = 8429597252274491314L;
+
     private static final XMLOutputter DEFAULT_OUTPUTTER = new XMLOutputter();
 
+    static
+    {
+        DEFAULT_OUTPUTTER.getFormat().setLineSeparator(System.getProperty("line.separator"));
+    }
+
     /**
      * <p>
      * This will create a new <code>AnakiaElement</code>
      *   with the supplied (local) name, and define
      *   the <code>{@link Namespace}</code> to be used.
-     * If the provided namespace is null, the element will have 
+     * If the provided namespace is null, the element will have
      * no namespace.
      * </p>
      *
      * @param name <code>String</code> name of element.
-     * @namespace <code>Namespace</code> to put element in.
+     * @param namespace <code>Namespace</code> to put element in.
      */
     public AnakiaElement(String name, Namespace namespace)
     {
@@ -91,6 +104,7 @@ public class AnakiaElement extends Element
      * </p>
      *
      * @param name <code>String</code> name of element.
+     * @param prefix The prefix of the element.
      * @param uri <code>String</code> URI for <code>Namespace</code> element
      *        should be in.
      */
@@ -98,7 +112,7 @@ public class AnakiaElement extends Element
     {
         super(name, prefix, uri);
     }
-    
+
     /**
      * Applies an XPath expression to this element and returns the resulting
      * node list. In order for this method to work, your application must have
@@ -121,42 +135,46 @@ public class AnakiaElement extends Element
     /**
      * Returns the XML serialized form of this element, as produced by the default
      * {@link XMLOutputter}.
+
+     * @return The XML serialized form of this element, as produced by the default
+     * {@link XMLOutputter}.
      */
+
     public String toString()
     {
         return DEFAULT_OUTPUTTER.outputString(this);
     }
-    
+
     /**
      * <p>
      * This returns the full content of the element as a NodeList which
      * may contain objects of type <code>String</code>, <code>Element</code>,
      * <code>Comment</code>, <code>ProcessingInstruction</code>,
-     * <code>CDATA</code>, and <code>EntityRef</code>.  
-     * The List returned is "live" in document order and modifications 
-     * to it affect the element's actual contents.  Whitespace content is 
+     * <code>CDATA</code>, and <code>EntityRef</code>.
+     * The List returned is "live" in document order and modifications
+     * to it affect the element's actual contents.  Whitespace content is
      * returned in its entirety.
      * </p>
      *
      * @return a <code>List</code> containing the mixed content of the
      *         element: may contain <code>String</code>,
-     *         <code>{@link Element}</code>, <code>{@link Comment}</code>,
-     *         <code>{@link ProcessingInstruction}</code>,
-     *         <code>{@link CDATA}</code>, and
-     *         <code>{@link EntityRef}</code> objects.
+     *         <code>{@link Element}</code>, <code>{@link org.jdom.Comment}</code>,
+     *         <code>{@link org.jdom.ProcessingInstruction}</code>,
+     *         <code>{@link org.jdom.CDATA}</code>, and
+     *         <code>{@link org.jdom.EntityRef}</code> objects.
      */
     public List getContent()
     {
         return new NodeList(super.getContent(), false);
     }
-    
+
     /**
      * <p>
      * This returns a <code>NodeList</code> of all the child elements
-     * nested directly (one level deep) within this element, as 
-     * <code>Element</code> objects.  If this target element has no nested 
+     * nested directly (one level deep) within this element, as
+     * <code>Element</code> objects.  If this target element has no nested
      * elements, an empty List is returned.  The returned list is "live"
-     * in document order and changes to it affect the element's actual 
+     * in document order and changes to it affect the element's actual
      * contents.
      * </p>
      * <p>
@@ -185,14 +203,14 @@ public class AnakiaElement extends Element
      * <p>
      * This returns a <code>NodeList</code> of all the child elements
      * nested directly (one level deep) within this element with the given
-     * local name and belonging to no namespace, returned as 
-     * <code>Element</code> objects.  If this target element has no nested 
-     * elements with the given name outside a namespace, an empty List 
+     * local name and belonging to no namespace, returned as
+     * <code>Element</code> objects.  If this target element has no nested
+     * elements with the given name outside a namespace, an empty List
      * is returned.  The returned list is "live" in document order
      * and changes to it affect the element's actual contents.
      * </p>
      * <p>
-     * Please see the notes for <code>{@link #getChildren}</code>
+     * Please see the notes for <code>{@link #getChildren()}</code>
      * for a code example.
      * </p>
      *
@@ -208,14 +226,14 @@ public class AnakiaElement extends Element
      * <p>
      * This returns a <code>NodeList</code> of all the child elements
      * nested directly (one level deep) within this element with the given
-     * local name and belonging to the given Namespace, returned as 
-     * <code>Element</code> objects.  If this target element has no nested 
-     * elements with the given name in the given Namespace, an empty List 
+     * local name and belonging to the given Namespace, returned as
+     * <code>Element</code> objects.  If this target element has no nested
+     * elements with the given name in the given Namespace, an empty List
      * is returned.  The returned list is "live" in document order
      * and changes to it affect the element's actual contents.
      * </p>
      * <p>
-     * Please see the notes for <code>{@link #getChildren}</code>
+     * Please see the notes for <code>{@link #getChildren()}</code>
      * for a code example.
      * </p>
      *
@@ -230,10 +248,10 @@ public class AnakiaElement extends Element
 
     /**
      * <p>
-     * This returns the complete set of attributes for this element, as a 
-     * <code>NodeList</code> of <code>Attribute</code> objects in no particular 
-     * order, or an empty list if there are none.  
-     * The returned list is "live" and changes to it affect the 
+     * This returns the complete set of attributes for this element, as a
+     * <code>NodeList</code> of <code>Attribute</code> objects in no particular
+     * order, or an empty list if there are none.
+     * The returned list is "live" and changes to it affect the
      * element's actual attributes.
      * </p>
      *
