@@ -1,27 +1,43 @@
 package org.apache.velocity.anakia;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
-import java.io.Writer;
 import java.io.IOException;
 import java.io.StringWriter;
-import java.util.*;
-import org.jdom.*;
-import org.jdom.output.*;
+import java.io.Writer;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Iterator;
+import java.util.List;
+import java.util.ListIterator;
+
+import org.jdom.Attribute;
+import org.jdom.CDATA;
+import org.jdom.Comment;
+import org.jdom.DocType;
+import org.jdom.Document;
+import org.jdom.Element;
+import org.jdom.EntityRef;
+import org.jdom.ProcessingInstruction;
+import org.jdom.Text;
+import org.jdom.output.XMLOutputter;
 
 /**
  * Provides a class for wrapping a list of JDOM objects primarily for use in template
@@ -35,13 +51,13 @@ import org.jdom.output.*;
  * sublist into a <code>NodeList</code>).
  *
  * @author <a href="mailto:szegedia@freemail.hu">Attila Szegedi</a>
- * @version $Id: NodeList.java,v 1.2.4.1 2004/03/03 23:22:04 geirm Exp $
+ * @version $Id: NodeList.java 463298 2006-10-12 16:10:32Z henning $
  */
 public class NodeList implements List, Cloneable
 {
-    private static final AttributeXMLOutputter DEFAULT_OUTPUTTER = 
+    private static final AttributeXMLOutputter DEFAULT_OUTPUTTER =
         new AttributeXMLOutputter();
-    
+
     /** The contained nodes */
     private List nodes;
 
@@ -55,6 +71,7 @@ public class NodeList implements List, Cloneable
 
     /**
      * Creates a node list that holds a single {@link Document} node.
+     * @param document
      */
     public NodeList(Document document)
     {
@@ -63,6 +80,7 @@ public class NodeList implements List, Cloneable
 
     /**
      * Creates a node list that holds a single {@link Element} node.
+     * @param element
      */
     public NodeList(Element element)
     {
@@ -79,10 +97,10 @@ public class NodeList implements List, Cloneable
         nodes = new ArrayList(1);
         nodes.add(object);
     }
-    
+
     /**
-     * Creates a node list that holds a list of nodes. 
-     * @param nodes the list of nodes this template should hold. The created 
+     * Creates a node list that holds a list of nodes.
+     * @param nodes the list of nodes this template should hold. The created
      * template will copy the passed nodes list, so changes to the passed list
      * will not affect the model.
      */
@@ -90,9 +108,9 @@ public class NodeList implements List, Cloneable
     {
         this(nodes, true);
     }
-    
+
     /**
-     * Creates a node list that holds a list of nodes. 
+     * Creates a node list that holds a list of nodes.
      * @param nodes the list of nodes this template should hold.
      * @param copy if true, the created template will copy the passed nodes
      * list, so changes to the passed list will not affect the model. If false,
@@ -108,12 +126,13 @@ public class NodeList implements List, Cloneable
         }
         this.nodes = copy ? new ArrayList(nodes) : nodes;
     }
-    
+
     /**
      * Retrieves the underlying list used to store the nodes. Note however, that
      * you can fully use the underlying list through the <code>List</code> interface
      * of this class itself. You would probably access the underlying list only for
      * synchronization purposes.
+     * @return The internal node List.
      */
     public List getList()
     {
@@ -121,12 +140,13 @@ public class NodeList implements List, Cloneable
     }
 
     /**
-     * This method returns the string resulting from concatenation of string 
+     * This method returns the string resulting from concatenation of string
      * representations of its nodes. Each node is rendered using its XML
      * serialization format. This greatly simplifies creating XML-transformation
      * templates, as to output a node contained in variable x as XML fragment,
      * you simply write ${x} in the template (or whatever your template engine
      * uses as its expression syntax).
+     * @return The Nodelist as printable object.
      */
     public String toString()
     {
@@ -180,9 +200,9 @@ public class NodeList implements List, Cloneable
                 else
                 {
                     throw new IllegalArgumentException(
-                        "Cannot process a " + 
-                        (node == null 
-                         ? "null node" 
+                        "Cannot process a " +
+                        (node == null
+                         ? "null node"
                          : "node of class " + node.getClass().getName()));
                 }
             }
@@ -197,6 +217,7 @@ public class NodeList implements List, Cloneable
 
     /**
      * Returns a NodeList that contains the same nodes as this node list.
+     * @return A clone of this list.
      * @throws CloneNotSupportedException if the contained list's class does
      * not have an accessible no-arg constructor.
      */
@@ -207,7 +228,7 @@ public class NodeList implements List, Cloneable
         clonedList.cloneNodes();
         return clonedList;
     }
-    
+
     private void cloneNodes()
         throws CloneNotSupportedException
     {
@@ -229,18 +250,19 @@ public class NodeList implements List, Cloneable
             // Cannot happen as listClass represents a concrete, non-primitive,
             // non-array, non-void class - there's an instance of it in "nodes"
             // which proves these assumptions.
-            throw new Error(); 
+            throw new Error();
         }
     }
 
     /**
      * Returns the hash code of the contained list.
+     * @return The hashcode of the list.
      */
     public int hashCode()
     {
         return nodes.hashCode();
     }
-    
+
     /**
      * Tests for equality with another object.
      * @param o the object to test for equality
@@ -249,11 +271,11 @@ public class NodeList implements List, Cloneable
      */
     public boolean equals(Object o)
     {
-        return o instanceof NodeList 
+        return o instanceof NodeList
             ? ((NodeList)o).nodes.equals(nodes)
             : false;
     }
-    
+
     /**
      * Applies an XPath expression to the node list and returns the resulting
      * node list. In order for this method to work, your application must have
@@ -264,7 +286,7 @@ public class NodeList implements List, Cloneable
      * usually kept in the parsed template, this ensures that each XPath
      * expression is parsed only once during the lifetime of the template that
      * first invoked it.
-     * @param xpathExpression the XPath expression you wish to apply
+     * @param xpathString the XPath expression you wish to apply
      * @return a NodeList representing the nodes that are the result of
      * application of the XPath to the current node list. It can be empty.
      */
@@ -275,139 +297,213 @@ public class NodeList implements List, Cloneable
 
 // List methods implemented hereafter
 
+    /**
+     * @see java.util.List#add(java.lang.Object)
+     */
     public boolean add(Object o)
     {
         return nodes.add(o);
     }
 
+    /**
+     * @see java.util.List#add(int, java.lang.Object)
+     */
     public void add(int index, Object o)
     {
         nodes.add(index, o);
     }
 
+    /**
+     * @see java.util.List#addAll(java.util.Collection)
+     */
     public boolean addAll(Collection c)
     {
         return nodes.addAll(c);
     }
 
+    /**
+     * @see java.util.List#addAll(int, java.util.Collection)
+     */
     public boolean addAll(int index, Collection c)
     {
         return nodes.addAll(index, c);
     }
 
+    /**
+     * @see java.util.List#clear()
+     */
     public void clear()
     {
         nodes.clear();
     }
 
+    /**
+     * @see java.util.List#contains(java.lang.Object)
+     */
     public boolean contains(Object o)
     {
         return nodes.contains(o);
     }
 
+    /**
+     * @see java.util.List#containsAll(java.util.Collection)
+     */
     public boolean containsAll(Collection c)
     {
         return nodes.containsAll(c);
     }
 
+    /**
+     * @see java.util.List#get(int)
+     */
     public Object get(int index)
     {
         return nodes.get(index);
     }
 
+    /**
+     * @see java.util.List#indexOf(java.lang.Object)
+     */
     public int indexOf(Object o)
     {
         return nodes.indexOf(o);
     }
 
+    /**
+     * @see java.util.List#isEmpty()
+     */
     public boolean isEmpty()
     {
         return nodes.isEmpty();
     }
 
+    /**
+     * @see java.util.List#iterator()
+     */
     public Iterator iterator()
     {
         return nodes.iterator();
     }
 
+    /**
+     * @see java.util.List#lastIndexOf(java.lang.Object)
+     */
     public int lastIndexOf(Object o)
     {
         return nodes.lastIndexOf(o);
     }
 
+    /**
+     * @see java.util.List#listIterator()
+     */
     public ListIterator listIterator()
     {
         return nodes.listIterator();
     }
 
+    /**
+     * @see java.util.List#listIterator(int)
+     */
     public ListIterator listIterator(int index)
     {
         return nodes.listIterator(index);
     }
 
+    /**
+     * @see java.util.List#remove(int)
+     */
     public Object remove(int index)
     {
         return nodes.remove(index);
     }
 
+    /**
+     * @see java.util.List#remove(java.lang.Object)
+     */
     public boolean remove(Object o)
     {
         return nodes.remove(o);
     }
 
+    /**
+     * @see java.util.List#removeAll(java.util.Collection)
+     */
     public boolean removeAll(Collection c)
     {
         return nodes.removeAll(c);
     }
 
+    /**
+     * @see java.util.List#retainAll(java.util.Collection)
+     */
     public boolean retainAll(Collection c)
     {
         return nodes.retainAll(c);
     }
 
+    /**
+     * @see java.util.List#set(int, java.lang.Object)
+     */
     public Object set(int index, Object o)
     {
         return nodes.set(index, o);
     }
 
+    /**
+     * @see java.util.List#size()
+     */
     public int size()
     {
         return nodes.size();
     }
 
+    /**
+     * @see java.util.List#subList(int, int)
+     */
     public List subList(int fromIndex, int toIndex)
     {
         return new NodeList(nodes.subList(fromIndex, toIndex));
     }
 
+    /**
+     * @see java.util.List#toArray()
+     */
     public Object[] toArray()
     {
         return nodes.toArray();
     }
 
+    /**
+     * @see java.util.List#toArray(java.lang.Object[])
+     */
     public Object[] toArray(Object[] a)
     {
         return nodes.toArray(a);
     }
 
     /**
-     * A special subclass of XMLOutputter that will be used to output 
+     * A special subclass of XMLOutputter that will be used to output
      * Attribute nodes. As a subclass of XMLOutputter it can use its protected
      * method escapeAttributeEntities() to serialize the attribute
      * appropriately.
      */
     private static final class AttributeXMLOutputter extends XMLOutputter
     {
+        /**
+         * @param attribute
+         * @param out
+         * @throws IOException
+         */
         public void output(Attribute attribute, Writer out)
             throws IOException
         {
             out.write(" ");
             out.write(attribute.getQualifiedName());
             out.write("=");
-            
+
             out.write("\"");
             out.write(escapeAttributeEntities(attribute.getValue()));
-            out.write("\"");            
+            out.write("\"");
         }
     }
 }
