@@ -1,36 +1,39 @@
 package org.apache.velocity.app;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
-import java.lang.Class;
 import java.lang.reflect.Field;
 import java.lang.reflect.Modifier;
 import java.util.HashMap;
+import org.apache.velocity.util.ClassUtils;
 
 /**
  *  <p>
  *  This is a small utility class allow easy access to static fields in a class,
  *  such as string constants.  Velocity will not introspect for class
- *  fields (and won't in the future :), but writing setter/getter methods to do 
+ *  fields (and won't in the future :), but writing setter/getter methods to do
  *  this really is a pain,  so use this if you really have
  *  to access fields.
- *  
+ *
  *  <p>
- *  The idea it so enable access to the fields just like you would in Java.  
+ *  The idea it so enable access to the fields just like you would in Java.
  *  For example, in Java, you would access a static field like
  *  <blockquote><pre>
  *  MyClass.STRING_CONSTANT
@@ -43,8 +46,8 @@ import java.util.HashMap;
  *   context.put("runtime", new FieldMethodizer( "org.apache.velocity.runtime.Runtime" ));
  *  </pre></blockquote>
  *  and then in your template, you can access any of your static fields in this way :
- *  <blockquote><pre>  
- *   $runtime.RUNTIME_LOG_WARN_STACKTRACE
+ *  <blockquote><pre>
+ *   $runtime.COUNTER_NAME
  *  </pre></blockquote>
  *
  *  <p>
@@ -54,16 +57,13 @@ import java.util.HashMap;
  *  to handle them by explicitly placing them into the context.
  *
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
- * @version $Id: FieldMethodizer.java,v 1.3.14.1 2004/03/03 23:22:53 geirm Exp $ 
+ * @version $Id: FieldMethodizer.java 652755 2008-05-02 04:00:58Z nbubna $
  */
 public class FieldMethodizer
 {
     /** Hold the field objects by field name */
     private HashMap fieldHash = new HashMap();
 
-    /** Hold the class objects by field name */
-    private HashMap classHash = new HashMap();
-
     /**
      * Allow object to be initialized without any data. You would use
      * addObject() to add data later.
@@ -86,7 +86,9 @@ public class FieldMethodizer
         }
         catch( Exception e )
         {
-            System.out.println( e );
+            System.err.println("Could not add " + s
+                    + " for field methodizing: "
+                    + e.getMessage());
         }
     }
 
@@ -96,7 +98,7 @@ public class FieldMethodizer
      *  only methodized the public static fields of
      *  the class.
      *
-     *  @param s Name of class to methodize.
+     *  @param o Name of class to methodize.
      */
     public FieldMethodizer( Object o )
     {
@@ -106,21 +108,27 @@ public class FieldMethodizer
         }
         catch( Exception e )
         {
-            System.out.println( e );
+            System.err.println("Could not add " + o
+                    + " for field methodizing: "
+                    + e.getMessage());
         }
     }
-    
+
     /**
      * Add the Name of the class to methodize
+     * @param s
+     * @throws Exception
      */
     public void addObject ( String s )
         throws Exception
     {
-        inspect(Class.forName(s));
+        inspect(ClassUtils.getClass(s));
     }
-    
+
     /**
      * Add an Object to methodize
+     * @param o
+     * @throws Exception
      */
     public void addObject ( Object o )
         throws Exception
@@ -137,16 +145,21 @@ public class FieldMethodizer
      */
     public Object get( String fieldName )
     {
-        try 
+        Object value = null;
+        try
         {
             Field f = (Field) fieldHash.get( fieldName );
             if (f != null)
-                return f.get( (Class) classHash.get(fieldName) );
+            {
+                value = f.get(null);
+            }
         }
-        catch( Exception e )
+        catch( IllegalAccessException e )
         {
+            System.err.println("IllegalAccessException while trying to access " + fieldName
+                    + ": " + e.getMessage());
         }
-        return null;
+        return value;
     }
 
     /**
@@ -165,7 +178,6 @@ public class FieldMethodizer
             if ( Modifier.isStatic(mod) && Modifier.isPublic(mod) )
             {
                 fieldHash.put(fields[i].getName(), fields[i]);
-                classHash.put(fields[i].getName(), clas);
             }
         }
     }
