@@ -1,46 +1,42 @@
 package org.apache.velocity.app;
 
 /*
- * Copyright 2000-2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 
+import java.io.BufferedReader;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.io.Reader;
+import java.io.UnsupportedEncodingException;
 import java.io.Writer;
 import java.util.Properties;
-import java.io.InputStream;
-import java.io.IOException;
-import java.io.Reader;
-import java.io.BufferedReader;
-import java.io.StringReader;
-import java.io.InputStreamReader;
-import java.io.UnsupportedEncodingException;
-
-import org.apache.velocity.context.Context;
-import org.apache.velocity.Template;
-import org.apache.velocity.context.InternalContextAdapterImpl;
-import org.apache.velocity.runtime.RuntimeInstance;
-import org.apache.velocity.runtime.RuntimeConstants;
-import org.apache.velocity.runtime.parser.node.SimpleNode;
-import org.apache.velocity.runtime.configuration.Configuration;
-
-import org.apache.velocity.exception.ResourceNotFoundException;
-import org.apache.velocity.exception.ParseErrorException;
-import org.apache.velocity.exception.MethodInvocationException;
-
-import org.apache.velocity.runtime.parser.ParseException;
 
 import org.apache.commons.collections.ExtendedProperties;
+import org.apache.velocity.Template;
+import org.apache.velocity.context.Context;
+import org.apache.velocity.exception.MethodInvocationException;
+import org.apache.velocity.exception.ParseErrorException;
+import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.velocity.runtime.RuntimeInstance;
+import org.apache.velocity.runtime.log.Log;
 
 /**
  * <p>
@@ -49,33 +45,50 @@ import org.apache.commons.collections.ExtendedProperties;
  * is using the Velocity class which employs the singleton
  * model.
  * </p>
- *
- * <p>
- * Please ensure that you call one of the init() variants. 
- * This is critical for proper behavior.  
- * </p>
- *
- * <p> Coming soon : Velocity will call
+ * <p>Velocity will call
  * the parameter-less init() at the first use of this class
  * if the init() wasn't explicitly called.  While this will
- * ensure that Velocity functions, it almost certainly won't
- * function in the way you intend, so please make sure to
- * call init().
+ * ensure that Velocity functions, it probably won't
+ * function in the way you intend, so it is strongly recommended that
+ * you call an init() method yourself if you use the default constructor.
  * </p>
  *
- * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
- * @version $Id: VelocityEngine.java,v 1.6.4.1 2004/03/03 23:22:53 geirm Exp $
+ * @version $Id: VelocityEngine.java 894920 2009-12-31 18:35:25Z nbubna $
  */
 public class VelocityEngine implements RuntimeConstants
 {
     private RuntimeInstance ri = new RuntimeInstance();
 
     /**
-     *  initialize the Velocity runtime engine, using the default 
+     *  Init-less CTOR
+     */
+    public VelocityEngine()
+    {
+        // do nothing
+    }
+
+    /**
+     * Construct a VelocityEngine with the initial properties defined in the file
+     * propsFilename
+     */
+    public VelocityEngine(String propsFilename)
+    {
+        ri.setProperties(propsFilename);
+    }
+
+    /**
+     * Construct a VelocityEngine instance with the specified initial properties.
+     */
+    public VelocityEngine(Properties p)
+    {
+        ri.setProperties(p);
+    }
+
+    /**
+     *  initialize the Velocity runtime engine, using the default
      *  properties of the Velocity distribution
      */
-    public void init() 
-        throws Exception
+    public void init()
     {
         ri.init();
     }
@@ -84,11 +97,10 @@ public class VelocityEngine implements RuntimeConstants
      *  initialize the Velocity runtime engine, using default properties
      *  plus the properties in the properties file passed in as the arg
      *
-     *  @param propsFilename file containing properties to use to initialize 
+     *  @param propsFilename file containing properties to use to initialize
      *         the Velocity runtime
      */
-    public void init( String propsFilename ) 
-        throws Exception
+    public void init(String propsFilename)
     {
         ri.init(propsFilename);
     }
@@ -98,19 +110,17 @@ public class VelocityEngine implements RuntimeConstants
      *  plus the properties in the passed in java.util.Properties object
      *
      *  @param p  Proprties object containing initialization properties
-     *
      */
-    public void init( Properties p )
-        throws Exception
-    {      
-        ri.init( p ); 
+    public void init(Properties p)
+    {
+        ri.init(p);
     }
-    
+
     /**
      * Set a Velocity Runtime property.
      *
-     * @param String key
-     * @param Object value
+     * @param  key
+     * @param  value
      */
     public void setProperty(String key, Object value)
     {
@@ -120,8 +130,8 @@ public class VelocityEngine implements RuntimeConstants
     /**
      * Add a Velocity Runtime property.
      *
-     * @param String key
-     * @param Object value
+     * @param  key
+     * @param  value
      */
     public void addProperty(String key, Object value)
     {
@@ -136,30 +146,6 @@ public class VelocityEngine implements RuntimeConstants
     public void clearProperty(String key)
     {
         ri.clearProperty(key);
-    }        
-
-    /**
-     * Set an entire configuration at once. This is
-     * useful in cases where the parent application uses
-     * the Configuration class and the velocity configuration
-     * is a subset of the parent application's configuration.
-     *
-     * @param Configuration configuration
-     *
-     * @deprecated Use
-     *  {@link #setExtendedProperties( ExtendedProperties  ) }
-     */
-    public void setConfiguration(Configuration configuration)
-    {
-        /*
-         *  Yuk. We added a little helper to Configuration to 
-         *  help with deprecation.  The Configuration class
-         *  contains a 'shadow' ExtendedProperties
-         */
-
-        ExtendedProperties ep = configuration.getExtendedProperties();
-
-        ri.setConfiguration( ep );
     }
 
     /**
@@ -168,7 +154,7 @@ public class VelocityEngine implements RuntimeConstants
      * the ExtendedProperties class and the velocity configuration
      * is a subset of the parent application's configuration.
      *
-     * @param ExtendedProperties configuration
+     * @param  configuration
      *
      */
     public void setExtendedProperties( ExtendedProperties configuration)
@@ -189,25 +175,28 @@ public class VelocityEngine implements RuntimeConstants
     }
 
     /**
-     *  renders the input string using the context into the output writer. 
-     *  To be used when a template is dynamically constructed, or want to use 
+     *  renders the input string using the context into the output writer.
+     *  To be used when a template is dynamically constructed, or want to use
      *  Velocity as a token replacer.
      *
      *  @param context context to use in rendering input string
      *  @param out  Writer in which to render the output
-     *  @param logTag  string to be used as the template name for log 
+     *  @param logTag  string to be used as the template name for log
      *                 messages in case of error
      *  @param instring input string containing the VTL to be rendered
      *
      *  @return true if successful, false otherwise.  If false, see
      *             Velocity runtime log
+     * @throws ParseErrorException The template could not be parsed.
+     * @throws MethodInvocationException A method on a context object could not be invoked.
+     * @throws ResourceNotFoundException A referenced resource could not be loaded.
      */
-    public  boolean evaluate( Context context,  Writer out,  
+    public  boolean evaluate( Context context,  Writer out,
                                      String logTag, String instring )
         throws ParseErrorException, MethodInvocationException,
-        	ResourceNotFoundException, IOException
+            ResourceNotFoundException
     {
-        return evaluate( context, out, logTag, new BufferedReader( new StringReader( instring )) );
+        return ri.evaluate(context, out, logTag, instring);
     }
 
     /**
@@ -216,26 +205,29 @@ public class VelocityEngine implements RuntimeConstants
      *  use Velocity as a token replacer.
      *
      *  @param context context to use in rendering input string
-     *  @param out  Writer in which to render the output
+     *  @param writer  Writer in which to render the output
      *  @param logTag  string to be used as the template name for log messages
      *                 in case of error
      *  @param instream input stream containing the VTL to be rendered
      *
-     *  @return true if successful, false otherwise.  If false, see 
+     *  @return true if successful, false otherwise.  If false, see
      *               Velocity runtime log
+     * @throws ParseErrorException
+     * @throws MethodInvocationException
+     * @throws ResourceNotFoundException
+     * @throws IOException
      *  @deprecated Use
-     *  {@link #evaluate( Context context, Writer writer, 
+     *  {@link #evaluate( Context context, Writer writer,
      *      String logTag, Reader reader ) }
      */
-    public boolean evaluate( Context context, Writer writer, 
+    public boolean evaluate( Context context, Writer writer,
                                     String logTag, InputStream instream )
-        throws ParseErrorException, MethodInvocationException, 
-        	ResourceNotFoundException, IOException
+        throws ParseErrorException, MethodInvocationException,
+            ResourceNotFoundException, IOException
     {
         /*
          *  first, parse - convert ParseException if thrown
          */
-
         BufferedReader br  = null;
         String encoding = null;
 
@@ -245,7 +237,7 @@ public class VelocityEngine implements RuntimeConstants
             br = new BufferedReader(  new InputStreamReader( instream, encoding));
         }
         catch( UnsupportedEncodingException  uce )
-        {   
+        {
             String msg = "Unsupported input encoding : " + encoding
                 + " for template " + logTag;
             throw new ParseErrorException( msg );
@@ -260,161 +252,70 @@ public class VelocityEngine implements RuntimeConstants
      *  use Velocity as a token replacer.
      *
      *  @param context context to use in rendering input string
-     *  @param out  Writer in which to render the output
+     *  @param writer  Writer in which to render the output
      *  @param logTag  string to be used as the template name for log messages
      *                 in case of error
      *  @param reader Reader containing the VTL to be rendered
      *
-     *  @return true if successful, false otherwise.  If false, see 
+     *  @return true if successful, false otherwise.  If false, see
      *               Velocity runtime log
-     *
+     * @throws ParseErrorException The template could not be parsed.
+     * @throws MethodInvocationException A method on a context object could not be invoked.
+     * @throws ResourceNotFoundException A referenced resource could not be loaded.
      *  @since Velocity v1.1
      */
-    public boolean evaluate( Context context, Writer writer, 
-                                    String logTag, Reader reader )
-        throws ParseErrorException, MethodInvocationException, 
-        	ResourceNotFoundException,IOException
+    public boolean evaluate(Context context, Writer writer,
+                                    String logTag, Reader reader)
+        throws ParseErrorException, MethodInvocationException,
+            ResourceNotFoundException
     {
-        SimpleNode nodeTree = null;
-        
-        try
-        {
-            nodeTree = ri.parse( reader, logTag );        
-        }
-        catch ( ParseException pex )
-        {
-            throw  new ParseErrorException( pex.getMessage() );
-        }                
-     
-        /*
-         * now we want to init and render
-         */
-
-        if (nodeTree != null)
-        {
-            InternalContextAdapterImpl ica = 
-                new InternalContextAdapterImpl( context );
-            
-            ica.pushCurrentTemplateName( logTag );
-            
-            try
-            {
-                try
-                {
-                    nodeTree.init( ica, ri );
-                }
-                catch( Exception e )
-                {
-                    ri.error("Velocity.evaluate() : init exception for tag = " 
-                                  + logTag + " : " + e );
-                }
-                
-                /*
-                 *  now render, and let any exceptions fly
-                 */
-
-                nodeTree.render( ica, writer );
-            }
-            finally
-            {
-                ica.popCurrentTemplateName();
-            }
-            
-            return true;
-        }
-        
-        return false;
+        return ri.evaluate(context, writer, logTag, reader);
     }
 
-   
+
     /**
-     *  Invokes a currently registered Velocimacro with the parms provided
-     *  and places the rendered stream into the writer.
+     * Invokes a currently registered Velocimacro with the params provided
+     * and places the rendered stream into the writer.
+     * <br>
+     * Note : currently only accepts args to the VM if they are in the context.
      *
-     *  Note : currently only accepts args to the VM if they are in the context. 
-     *
-     *  @param vmName name of Velocimacro to call
-     *  @param logTag string to be used for template name in case of error
-     *  @param params[] args used to invoke Velocimacro. In context key format : 
-     *                  eg  "foo","bar" (rather than "$foo","$bar")
-     *  @param context Context object containing data/objects used for rendering.
-     *  @param writer  Writer for output stream
-     *  @return true if Velocimacro exists and successfully invoked, false otherwise.
+     * @param vmName name of Velocimacro to call
+     * @param logTag string to be used for template name in case of error. if null,
+     *               the vmName will be used
+     * @param params keys for args used to invoke Velocimacro, in java format
+     *               rather than VTL (eg  "foo" or "bar" rather than "$foo" or "$bar")
+     * @param context Context object containing data/objects used for rendering.
+     * @param writer  Writer for output stream
+     * @return true if Velocimacro exists and successfully invoked, false otherwise.
      */
-    public boolean invokeVelocimacro( String vmName, String logTag, 
-                                              String params[], Context context, 
+    public boolean invokeVelocimacro( String vmName, String logTag,
+                                              String params[], Context context,
                                               Writer writer )
-        throws Exception
     {
-        /*
-         *  check parms
-         */
-
-        if ( vmName == null ||  params == null ||  context == null 
-             || writer == null || logTag == null)
-        {
-            ri.error( "VelocityEngine.invokeVelocimacro() : invalid parameter");
-            return false;
-        }
-
-        /*
-         * does the VM exist?
-         */
-          
-        if (!ri.isVelocimacro( vmName, logTag ))
-        {
-            ri.error( "VelocityEngine.invokeVelocimacro() : VM '"+ vmName 
-                           + "' not registered.");
-            return false;
-        }
-
-        /*
-         *  now just create the VM call, and use evaluate
-         */
-
-        StringBuffer construct = new StringBuffer("#");
-
-        construct.append( vmName );
-        construct.append( "(" );
- 
-        for( int i = 0; i < params.length; i++)
-        {
-            construct.append( " $" );
-            construct.append( params[i] );
-        }
-
-        construct.append(" )");
-
-        try
-        {
-            boolean retval = evaluate(  context,  writer,  
-                                         logTag, construct.toString() );
-  
-            return retval;
-        }
-        catch( Exception  e )
-        {
-            ri.error( "VelocityEngine.invokeVelocimacro() : error " + e );
-            throw e;
-        }
+        return ri.invokeVelocimacro(vmName, logTag, params, context, writer);
     }
 
     /**
-     *  merges a template and puts the rendered stream into the writer
+     *  Merges a template and puts the rendered stream into the writer.
+     *  The default encoding that Velocity uses to read template files is defined in
+     *  the property input.encoding and defaults to ISO-8859-1.
      *
      *  @param templateName name of template to be used in merge
      *  @param context  filled context to be used in merge
      *  @param  writer  writer to write template into
      *
-     *  @return true if successful, false otherwise.  Errors 
+     *  @return true if successful, false otherwise.  Errors
      *           logged to velocity log.
-     * *  @deprecated Use
+     * @throws ResourceNotFoundException
+     * @throws ParseErrorException
+     * @throws MethodInvocationException
+     * @deprecated Use
      *  {@link #mergeTemplate( String templateName, String encoding,
      *                Context context, Writer writer )}
      */
-    public boolean mergeTemplate( String templateName, 
+    public boolean mergeTemplate( String templateName,
                                          Context context, Writer writer )
-        throws ResourceNotFoundException, ParseErrorException, MethodInvocationException, Exception
+        throws ResourceNotFoundException, ParseErrorException, MethodInvocationException
     {
         return mergeTemplate( templateName, ri.getString(INPUT_ENCODING,ENCODING_DEFAULT),
                                context, writer );
@@ -428,22 +329,25 @@ public class VelocityEngine implements RuntimeConstants
      *  @param context  filled context to be used in merge
      *  @param  writer  writer to write template into
      *
-     *  @return true if successful, false otherwise.  Errors 
+     *  @return true if successful, false otherwise.  Errors
      *           logged to velocity log
-     *
+     * @throws ResourceNotFoundException
+     * @throws ParseErrorException
+     * @throws MethodInvocationException
      *  @since Velocity v1.1
      */
     public boolean mergeTemplate( String templateName, String encoding,
                                       Context context, Writer writer )
-        throws ResourceNotFoundException, ParseErrorException, MethodInvocationException, Exception
+        throws ResourceNotFoundException, ParseErrorException, MethodInvocationException
     {
         Template template = ri.getTemplate(templateName, encoding);
-        
+
         if ( template == null )
         {
-            ri.error("Velocity.parseTemplate() failed loading template '" 
-                          + templateName + "'" );
-            return false;
+            String msg = "VelocityEngine.mergeTemplate() was unable to load template '"
+                           + templateName + "'";
+            getLog().error(msg);
+            throw new ResourceNotFoundException(msg);
         }
         else
         {
@@ -462,10 +366,9 @@ public class VelocityEngine implements RuntimeConstants
      *          from any available source.
      * @throws ParseErrorException if template cannot be parsed due
      *          to syntax (or other) error.
-     * @throws Exception if an error occurs in template initialization
      */
     public Template getTemplate(String name)
-        throws ResourceNotFoundException, ParseErrorException, Exception
+        throws ResourceNotFoundException, ParseErrorException
     {
         return ri.getTemplate( name );
     }
@@ -481,92 +384,109 @@ public class VelocityEngine implements RuntimeConstants
      *          from any available source.
      * @throws ParseErrorException if template cannot be parsed due
      *          to syntax (or other) error.
-     * @throws Exception if an error occurs in template initialization
-     *
      *  @since Velocity v1.1
      */
     public Template getTemplate(String name, String encoding)
-        throws ResourceNotFoundException, ParseErrorException, Exception
+        throws ResourceNotFoundException, ParseErrorException
     {
         return ri.getTemplate( name, encoding );
     }
 
     /**
-     *   Determines if a template is accessable via the currently 
+     *   Determines if a resource is accessable via the currently
      *   configured resource loaders.
      *   <br><br>
      *   Note that the current implementation will <b>not</b>
      *   change the state of the system in any real way - so this
-     *   cannot be used to pre-load the resource cache, as the 
-     *   previous implementation did as a side-effect. 
+     *   cannot be used to pre-load the resource cache, as the
+     *   previous implementation did as a side-effect.
      *   <br><br>
      *   The previous implementation exhibited extreme lazyness and
      *   sloth, and the author has been flogged.
      *
-     *   @param templateName  name of the temlpate to search for
+     *   @param resourceName  name of the resource to search for
      *   @return true if found, false otherwise
+     *   @since 1.5
      */
-    public boolean templateExists( String templateName )
+    public boolean resourceExists(String resourceName)
     {
-        return (ri.getLoaderNameForResource(templateName) != null);
+        return (ri.getLoaderNameForResource(resourceName) != null);
     }
-    
+
     /**
-     * Log a warning message.
-     *
-     * @param Object message to log
+     * @param resourceName
+     * @return True if the template exists.
+     * @see #resourceExists(String)
+     * @deprecated Use resourceExists(String) instead.
+     */
+    public boolean templateExists(String resourceName)
+    {
+        return resourceExists(resourceName);
+    }
+
+
+    /**
+     * Returns a convenient Log instance that wraps the current LogChute.
+     * Use this to log error messages. It has the usual methods you'd expect.
+     * @return A log object.
+     * @since 1.5
+     */
+    public Log getLog()
+    {
+        return ri.getLog();
+    }
+
+    /**
+     * @param message
+     * @deprecated Use getLog() and call warn() on it.
      */
     public void warn(Object message)
     {
-        ri.warn( message );
+        getLog().warn(message);
     }
-    
-    /** 
-     * Log an info message.
-     *
-     * @param Object message to log
+
+    /**
+     * @param message
+     * @deprecated Use getLog() and call warn() on it.
      */
     public void info(Object message)
     {
-        ri.info( message );
+        getLog().info(message);
     }
-    
+
     /**
-     * Log an error message.
-     *
-     * @param Object message to log
+     * @param message
+     * @deprecated Use getLog() and call warn() on it.
      */
     public void error(Object message)
     {
-        ri.error( message );
+        getLog().error(message);
     }
-    
+
     /**
-     * Log a debug message.
-     *
-     * @param Object message to log
+     * @param message
+     * @deprecated Use getLog() and call warn() on it.
      */
     public void debug(Object message)
     {
-        ri.debug( message );
+        getLog().debug(message);
     }
 
     /**
      *  <p>
-     *  Set the an ApplicationAttribue, which is an Object
-     *  set by the application which is accessable from
-     *  any component of the system that gets a RuntimeServices.
-     *  This allows communication between the application
-     *  environment and custom pluggable components of the
-     *  Velocity engine, such as loaders and loggers.
+     *  Sets an application attribute (which can be any Object) that will be
+     *  accessible from any component of the system that gets a
+     *  RuntimeServices. This allows communication between the application
+     *  environment and custom pluggable components of the Velocity engine,
+     *  such as ResourceLoaders and LogChutes.
      *  </p>
      *
      *  <p>
-     *  Note that there is no enfocement or rules for the key
+     *  Note that there is no enforcement or rules for the key
      *  used - it is up to the application developer.  However, to
      *  help make the intermixing of components possible, using
-     *  the target Class name (e.g.  com.foo.bar ) as the key
-     *   might help avoid collision.
+     *  the target Class name (e.g. com.foo.bar ) as the key
+     *  might help avoid collision.
      *  </p>
      *
      *  @param key object 'name' under which the object is stored
@@ -574,9 +494,44 @@ public class VelocityEngine implements RuntimeConstants
      */
      public void setApplicationAttribute( Object key, Object value )
      {
-        ri.setApplicationAttribute( key, value );
+        ri.setApplicationAttribute(key, value);
      }
-} 
 
+     /**
+      *  <p>
+      *  Return an application attribute (which can be any Object)
+      *  that was set by the application in order to be accessible from
+      *  any component of the system that gets a RuntimeServices.
+      *  This allows communication between the application
+      *  environment and custom pluggable components of the
+      *  Velocity engine, such as ResourceLoaders and LogChutes.
+      *  </p>
+      *
+      *  @param key object 'name' under which the object is stored
+      *  @return value object to store under this key
+      * @since 1.5
+      */
+     public Object getApplicationAttribute( Object key )
+     {
+        return ri.getApplicationAttribute(key);
+     }
 
+     /**
+      * Remove a directive.
+      * @param name name of the directive.
+      */
+     public void removeDirective(String name)
+     {
+        ri.removeDirective(name);
+     }
 
+     /**
+      * Instantiates and loads the directive with some basic checks.
+      *
+      * @param directiveClass classname of directive to load
+      */
+     public void loadDirective(String directiveClass)
+     {
+        ri.loadDirective(directiveClass);
+     }
+}
