@@ -1,43 +1,50 @@
 package org.apache.velocity.convert;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
 import java.io.File;
 import java.io.FileWriter;
+import java.io.IOException;
 
 import org.apache.oro.text.perl.Perl5Util;
 import org.apache.velocity.util.StringUtils;
 import org.apache.tools.ant.DirectoryScanner;
 
 /**
- * This class will convert a WebMacro template to
- * a Velocity template. Uses the ORO Regexp package to do the 
- * rewrites. Note, it isn't 100% perfect, but will definitely get
- * you about 99.99% of the way to a converted system. Please
- * see the website documentation for more information on how to use
- * this class.
+ * This is deprecated without replacement.
  *
  * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
  * @author <a href="mailto:dlr@finemaltcoding.com">Daniel Rall</a>
- * @version $Id: WebMacro.java,v 1.20.8.1 2004/03/03 23:22:54 geirm Exp $ 
+ * @version $Id: WebMacro.java 898028 2010-01-11 19:36:31Z nbubna $
+ * @deprecated Obsolete and outdated.
  */
 public class WebMacro
 {
+    /**
+     *
+     */
     protected static final String VM_EXT = ".vm";
+
+    /**
+     *
+     */
     protected static final String WM_EXT = ".wm";
 
     /**
@@ -101,22 +108,21 @@ public class WebMacro
         "\\.wm",
         ".vm"
     };
-    
+
     /**
      * Iterate through the set of find/replace regexes
      * that will convert a given WM template to a VM template
+     * @param target
      */
     public void convert(String target)
     {
         File file = new File(target);
-        
+
         if (!file.exists())
         {
-            System.err.println
-                ("The specified template or directory does not exist");
-            System.exit(1);
+            throw new RuntimeException("The specified template or directory does not exist");
         }
-        
+
         if (file.isDirectory())
         {
             String basedir = file.getAbsolutePath();
@@ -127,7 +133,7 @@ public class WebMacro
             ds.addDefaultExcludes();
             ds.scan();
             String[] files = ds.getIncludedFiles();
-            
+
             for (int i = 0; i < files.length; i++)
             {
                 writeTemplate(files[i], basedir, newBasedir);
@@ -150,48 +156,55 @@ public class WebMacro
         {
             return false;
         }
-    
-        System.out.println("Converting " + file + "...");
-        
-        String template;
-        String templateDir;
-        String newTemplate;
-        File outputDirectory;
-        
-        if (basedir.length() == 0)
-        {
-            template = file;
-            templateDir = "";
-            newTemplate = convertName(file);
-        }            
-        else
-        {
-            template = basedir + File.separator + file;
-            templateDir = newBasedir + extractPath(file);
 
-            outputDirectory = new File(templateDir);
-                
+        System.out.println("Converting " + file + "...");
+
+        String template = file;
+        String newTemplate = convertName(file);
+
+        if (basedir.length() > 0)
+        {
+            String templateDir = newBasedir + extractPath(file);
+            File outputDirectory = new File(templateDir);
+
+            template = basedir + File.separator + file;
+
+
             if (! outputDirectory.exists())
             {
                 outputDirectory.mkdirs();
             }
-                
+
             newTemplate = newBasedir + File.separator + convertName(file);
-        }            
-        
+        }
+
         String convertedTemplate = convertTemplate(template);
-                    
+
+        FileWriter fw = null;
         try
         {
-            FileWriter fw = new FileWriter(newTemplate);
+            fw = new FileWriter(newTemplate);
             fw.write(convertedTemplate);
-            fw.close();
         }
         catch (Exception e)
         {
             e.printStackTrace();
         }
-    
+        finally
+        {
+            if (fw != null)
+            {
+                try
+                {
+                    fw.close();
+                }
+                catch (IOException io)
+                {
+                    // Do nothing
+                }
+            }
+        }
+
         return true;
     }
 
@@ -211,14 +224,9 @@ public class WebMacro
      */
     private String convertName(String name)
     {
-        if (name.indexOf(WM_EXT) > 0)
-        {
-            return name.substring(0, name.indexOf(WM_EXT)) + VM_EXT;
-        }
-        else
-        {
-            return name;
-        }
+        return (name.indexOf(WM_EXT) < 0)
+                ? name
+                : name.substring(0, name.indexOf(WM_EXT)) + VM_EXT;
     }
 
     /**
@@ -227,11 +235,12 @@ public class WebMacro
     private static final void usage()
     {
         System.err.println("Usage: convert-wm <template.wm | directory>");
-        System.exit(1);
     }
 
     /**
      * Apply find/replace regexes to our WM template
+     * @param template
+     * @return Returns the template with all regexprs applied.
      */
     public String convertTemplate(String template)
     {
@@ -277,6 +286,7 @@ public class WebMacro
 
     /**
      * Main hook for the conversion process.
+     * @param args
      */
     public static void main(String[] args)
     {
