@@ -29,12 +29,15 @@ import org.apache.velocity.context.InternalContextAdapter;
 import org.apache.velocity.exception.MethodInvocationException;
 import org.apache.velocity.exception.TemplateInitException;
 import org.apache.velocity.exception.VelocityException;
-import org.apache.velocity.runtime.RuntimeConstants;
 import org.apache.velocity.runtime.Renderable;
+import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.velocity.runtime.directive.Block.Reference;
 import org.apache.velocity.runtime.log.Log;
 import org.apache.velocity.runtime.parser.Parser;
 import org.apache.velocity.runtime.parser.Token;
+import org.apache.velocity.util.ClassUtils;
 import org.apache.velocity.util.introspection.Info;
+import org.apache.velocity.util.introspection.VelMethod;
 import org.apache.velocity.util.introspection.VelPropertySet;
 
 /**
@@ -48,7 +51,7 @@ import org.apache.velocity.util.introspection.VelPropertySet;
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
  * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph Reck</a>
  * @author <a href="mailto:kjohnson@transparent.com>Kent Johnson</a>
- * @version $Id: ASTReference.java 730988 2009-01-03 14:15:56Z byron $
+ * @version $Id: ASTReference.java 832302 2009-11-03 05:32:31Z wglass $
 */
 public class ASTReference extends SimpleNode
 {
@@ -75,6 +78,27 @@ public class ASTReference extends SimpleNode
      */
     public boolean strictRef = false;
     
+    /**
+     * non null Indicates if we are setting an index reference e.g, $foo[2], which basically
+     * means that the last syntax of the reference are brackets.
+     */
+    private ASTIndex astIndex = null;
+    
+    /**
+     * Indicates if we are using modified escape behavior in strict mode.
+     * mainly we allow \$abc -> to render as $abc
+     */
+    public boolean strictEscape = false;
+    
+    /**
+     * Indicates if toString() should be called during condition evaluation just
+     * to ensure it does not return null. Check is unnecessary if all toString()
+     * implementations are known to have non-null return values. Disabling the
+     * check will give a performance improval since toString() may be a complex
+     * operation on large objects.
+     */
+    public boolean toStringNullCheck = true;
+    
     private int numChildren = 0;
 
     protected Info uberInfo;
@@ -110,35 +134,41 @@ public class ASTReference extends SimpleNode
     public Object init(InternalContextAdapter context, Object data)
     throws TemplateInitException
     {
-        /*
-         *  init our children
-         */
-
         super.init(context, data);
-
+        
+        strictEscape = rsvc.getBoolean(RuntimeConstants.RUNTIME_REFERENCES_STRICT_ESCAPE, false);
+        strictRef = rsvc.getBoolean(RuntimeConstants.RUNTIME_REFERENCES_STRICT, false);
+        toStringNullCheck = rsvc.getBoolean(RuntimeConstants.DIRECTIVE_IF_TOSTRING_NULLCHECK, true); 
+            
         /*
          *  the only thing we can do in init() is getRoot()
          *  as that is template based, not context based,
          *  so it's thread- and context-safe
          */
 
-        rootString = getRoot();
+        rootString = getRoot().intern();
 
         numChildren = jjtGetNumChildren();
-
+        
+        // This is an expensive call, so get it now.
+        literal = literal();
+        
         /*
          * and if appropriate...
          */
 
         if (numChildren > 0 )
         {
-            identifier = jjtGetChild(numChildren - 1).getFirstToken().image;
+            Node lastNode = jjtGetChild(numChildren-1);
+            if (lastNode instanceof ASTIndex)
+                astIndex = (ASTIndex)lastNode;
+            else
+                identifier = lastNode.getFirstToken().image;            
         }
 
         /*
          * make an uberinfo - saves new's later on
          */
-
         uberInfo = new Info(getTemplateName(), getLine(),getColumn());
 
         /*
@@ -147,8 +177,6 @@ public class ASTReference extends SimpleNode
         logOnNull =
             rsvc.getBoolean(RuntimeConstants.RUNTIME_LOG_REFERENCE_LOG_INVALID, true);
 
-        strictRef = rsvc.getBoolean(RuntimeConstants.RUNTIME_REFERENCES_STRICT, false);
- 
         /**
          * In the case we are referencing a variable with #if($foo) or
          * #if( ! $foo) then we allow variables to be undefined and we 
@@ -214,7 +242,7 @@ public class ASTReference extends SimpleNode
         if (result == null && !strictRef)
         {
             return EventHandlerUtil.invalidGetMethod(rsvc, context, 
-                    "$" + rootString, null, null, uberInfo);
+                    getDollarBang() + rootString, null, null, uberInfo);
         }
 
         /*
@@ -263,11 +291,11 @@ public class ASTReference extends SimpleNode
                 if (failedChild == -1)
                 {
                     result = EventHandlerUtil.invalidGetMethod(rsvc, context, 
-                            "$" + rootString, previousResult, null, uberInfo);                    
+                            getDollarBang() + rootString, previousResult, null, uberInfo);                    
                 }
                 else
                 {
-                    StringBuffer name = new StringBuffer("$").append(rootString);
+                    StringBuffer name = new StringBuffer(getDollarBang()).append(rootString);
                     for (int i = 0; i <= failedChild; i++)
                     {
                         Node node = jjtGetChild(i);
@@ -321,15 +349,25 @@ public class ASTReference extends SimpleNode
     {
         if (referenceType == RUNT)
         {
-            if (context.getAllowRendering())
-            {
-                writer.write(rootString);
-            }
-
+            writer.write(rootString);
             return true;
         }
 
-        Object value = execute(null, context);
+        Object value = null;
+        if (escaped && strictEscape)
+        {
+          /**
+           * If we are in strict mode and the variable is escaped, then don't bother to
+           * retreive the value since we won't use it. And if the var is not defined 
+           * it will throw an exception.  Set value to TRUE to fall through below with
+           * simply printing $foo, and not \$foo
+           */
+          value = Boolean.TRUE;
+        }
+        else
+        {
+          value = execute(null, context);
+        }
 
         String localNullString = null;
 
@@ -345,20 +383,14 @@ public class ASTReference extends SimpleNode
             
             if (value == null)
             {
-                if (context.getAllowRendering())
-                {
-                    writer.write(escPrefix);
-                    writer.write("\\");
-                    writer.write(localNullString);
-                }
+                writer.write(escPrefix);
+                writer.write("\\");
+                writer.write(localNullString);
             }
             else
             {
-                if (context.getAllowRendering())
-                {
-                    writer.write(escPrefix);
-                    writer.write(localNullString);
-                }
+                writer.write(escPrefix);
+                writer.write(localNullString);
             }
             return true;
         }
@@ -369,35 +401,77 @@ public class ASTReference extends SimpleNode
          * if we have an event cartridge, get a new value object
          */
 
-        value = EventHandlerUtil.referenceInsert(rsvc, context, literal(), value);
+        value = EventHandlerUtil.referenceInsert(rsvc, context, literal, value);
 
         String toString = null;
         if (value != null)
-        {
-
-            if(value instanceof Renderable && ((Renderable)value).render(context,writer))
+        {          
+            if (value instanceof Renderable)
             {
-                return true;
+                Renderable renderable = (Renderable)value;
+                try
+                {
+                    if (renderable.render(context,writer))
+                      return true;
+                }
+                catch(RuntimeException e)
+                {
+                    // We commonly get here when an error occurs within a block reference.
+                    // We want to log where the reference is at so that a developer can easily
+                    // know where the offending call is located.  This can be seen
+                    // as another element of the error stack we report to log.
+                    log.error("Exception rendering "
+                        + ((renderable instanceof Reference)? "block ":"Renderable ")
+                        + rootString + " at " + Log.formatFileString(this));
+                    throw e;
+                }
             }
 
             toString = value.toString();
         }
 
         if (value == null || toString == null)
-        {
-            /*
-             * write prefix twice, because it's schmoo, so the \ don't escape each other...
-             */
-
-            if (context.getAllowRendering())
+        {          
+            if (strictRef)
             {
-                localNullString = getNullString(context);
-
-                writer.write(escPrefix);
-                writer.write(escPrefix);
-                writer.write(morePrefix);
-                writer.write(localNullString);
+                if (referenceType != QUIET_REFERENCE)
+                {
+                  log.error("Prepend the reference with '$!' e.g., $!" + literal().substring(1)
+                      + " if you want Velocity to ignore the reference when it evaluates to null");
+                  if (value == null)
+                  {
+                    throw new VelocityException("Reference " + literal() 
+                        + " evaluated to null when attempting to render at " 
+                        + Log.formatFileString(this));
+                  }
+                  else  // toString == null
+                  {
+                    // This will probably rarely happen, but when it does we want to
+                    // inform the user that toString == null so they don't pull there
+                    // hair out wondering why Velocity thinks the value is null.                    
+                    throw new VelocityException("Reference " + literal()
+                        + " evaluated to object " + value.getClass().getName()
+                        + " whose toString() method returned null at "
+                        + Log.formatFileString(this));
+                  }
+                }              
+                return true;
             }
+          
+            /*
+             * write prefix twice, because it's schmoo, so the \ don't escape each
+             * other...
+             */
+            localNullString = getNullString(context);
+            if (!strictEscape)
+            {
+                // If in strict escape mode then we only print escape once.
+                // Yea, I know.. brittle stuff
+                writer.write(escPrefix);
+            }            
+            writer.write(escPrefix);
+            writer.write(morePrefix);
+            writer.write(localNullString);
 
             if (logOnNull && referenceType != QUIET_REFERENCE && log.isDebugEnabled())
             {
@@ -412,13 +486,9 @@ public class ASTReference extends SimpleNode
             /*
              * non-null processing
              */
-
-            if (context.getAllowRendering())
-            {
-                writer.write(escPrefix);
-                writer.write(morePrefix);
-                writer.write(toString);
-            }
+            writer.write(escPrefix);
+            writer.write(morePrefix);
+            writer.write(toString);
 
             return true;
         }
@@ -470,7 +540,7 @@ public class ASTReference extends SimpleNode
             else
                 return false;
         }        
-        else
+        else if (toStringNullCheck)
         {
             try
             {
@@ -482,6 +552,10 @@ public class ASTReference extends SimpleNode
                     + Log.formatFileString(this), e);
             }
         }
+        else
+        {
+            return true;
+        }
     }
 
     /**
@@ -493,6 +567,16 @@ public class ASTReference extends SimpleNode
         return (computableReference ? execute(null, context) : null);
     }
 
+    
+    /**
+     * Utility class to handle nulls when printing a class type
+     */
+    public static String printClass(Class clazz)
+    {
+      return clazz == null ? "null" : clazz.getName();
+    }
+    
+    
     /**
      *  Sets the value of a complex reference (something like $foo.bar)
      *  Currently used by ASTSetReference()
@@ -555,6 +639,75 @@ public class ASTReference extends SimpleNode
             }
         }
 
+        if (astIndex != null)
+        {
+            // If astIndex is not null then we are actually setting an index reference,
+            // something of the form $foo[1] =, or in general any reference that ends with
+            // the brackets.  This means that we need to call a more general method
+            // of the form set(Integer, <something>), or put(Object, <something), where
+            // the first parameter is the index value and the second is the LHS of the set.
+          
+            Object argument = astIndex.jjtGetChild(0).value(context);
+            // If negative, turn -1 into (size - 1)
+            argument = ASTIndex.adjMinusIndexArg(argument, result, context, astIndex);            
+            Object [] params = {argument, value};
+            Class[] paramClasses = {params[0] == null ? null : params[0].getClass(), 
+                                    params[1] == null ? null : params[1].getClass()};
+
+            String methodName = "set";
+            VelMethod method = ClassUtils.getMethod(methodName, params, paramClasses, 
+                result, context, astIndex, false);
+            
+            if (method == null)
+            {
+                // If we can't find a 'set' method, lets try 'put',  This warrents a little
+                // investigation performance wise... if the user is using the hash 
+                // form $foo["blaa"], then it may be expensive to first try and fail on 'set'
+                // then go to 'put'?  The problem is that getMethod will try the cache, then
+                // perform introspection on 'result' for 'set'
+                methodName = "put";
+                method = ClassUtils.getMethod(methodName, params, paramClasses, 
+                      result, context, astIndex, false);
+            }   
+            
+            if (method == null)
+            {
+                // couldn't find set or put method, so bail
+                if (strictRef)
+                {
+                    throw new VelocityException(
+                        "Found neither a 'set' or 'put' method with param types '("
+                        + printClass(paramClasses[0]) + "," + printClass(paramClasses[1])
+                        + ")' on class '" + result.getClass().getName() 
+                        + "' at " + Log.formatFileString(astIndex));
+                }
+                return false;
+            }
+          
+            try
+            { 
+                method.invoke(result, params);
+            }
+            catch(RuntimeException e)
+            {
+                // Kludge since invoke throws Exception, pass up Runtimes
+                throw e;
+            }
+            catch(Exception e)
+            {
+                throw new MethodInvocationException(
+                  "Exception calling method '"
+                  + methodName + "(" 
+                  + printClass(paramClasses[0]) + "," + printClass(paramClasses[1])
+                  + ")' in  " + result.getClass(),
+                  e.getCause(), identifier, astIndex.getTemplateName(), astIndex.getLine(), 
+                    astIndex.getColumn());
+            }
+            
+            return true;
+        }
+        
+        
         /*
          *  We support two ways of setting the value in a #set($ref.foo = $value ) :
          *  1) ref.setFoo( value )
@@ -634,6 +787,15 @@ public class ASTReference extends SimpleNode
 
         if (slashbang != -1)
         {
+            if (strictEscape)
+            {
+                // If we are in strict escape mode, then we consider this type of 
+                // pattern a non-reference, and we print it out as schmoo...
+                nullString = literal();
+                escaped = true;
+                return literal();
+            }
+          
             /*
              *  lets do all the work here.  I would argue that if this occurrs,
              *  it's not a reference at all, so preceeding \ characters in front
@@ -849,42 +1011,8 @@ public class ASTReference extends SimpleNode
         return obj;        
     }
 
-
-    /**
-     *  Routine to allow the literal representation to be
-     *  externally overridden.  Used now in the VM system
-     *  to override a reference in a VM tree with the
-     *  literal of the calling arg to make it work nicely
-     *  when calling arg is null.  It seems a bit much, but
-     *  does keep things consistant.
-     *
-     *  Note, you can only set the literal once...
-     *
-     *  @param literal String to render to when null
-     */
-    public void setLiteral(String literal)
+    public String getDollarBang()
     {
-        /*
-         * do only once
-         */
-
-        if( this.literal == null)
-            this.literal = literal;
-    }
-
-    /**
-     *  Override of the SimpleNode method literal()
-     *  Returns the literal representation of the
-     *  node.  Should be something like
-     *  $<token>.
-     * @return A literal string.
-     */
-    public String literal()
-    {
-        if (literal != null)
-            return literal;
-        
-        // this value could be cached in this.literal but it increases memory usage
-        return super.literal();
+        return (referenceType == QUIET_REFERENCE) ? "$!" : "$";
     }
 }
