@@ -1,19 +1,22 @@
 package org.apache.velocity.runtime.resource;
 
 /*
- * Copyright 2000-2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
 import org.apache.velocity.runtime.RuntimeServices;
@@ -28,7 +31,7 @@ import org.apache.velocity.exception.ParseErrorException;
  * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
  * @author <a href="mailto:paulo.gaspar@krankikom.de">Paulo Gaspar</a>
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
- * @version $Id: ResourceManager.java,v 1.34.4.1 2004/03/03 23:23:01 geirm Exp $
+ * @version $Id: ResourceManager.java 898050 2010-01-11 20:15:31Z nbubna $
  */
 public interface ResourceManager
 {
@@ -36,7 +39,7 @@ public interface ResourceManager
      * A template resources.
      */
     public static final int RESOURCE_TEMPLATE = 1;
-    
+
     /**
      * A static content resource.
      */
@@ -44,8 +47,9 @@ public interface ResourceManager
 
     /**
      * Initialize the ResourceManager.
+     * @param rs
      */
-    public void initialize( RuntimeServices rs ) throws Exception;
+    public void initialize( RuntimeServices rs );
 
     /**
      * Gets the named resource.  Returned class type corresponds to specified type
@@ -60,13 +64,12 @@ public interface ResourceManager
      *          from any available source.
      * @throws ParseErrorException if template cannot be parsed due
      *          to syntax (or other) error.
-     * @throws Exception if a problem in parse
      */
     public Resource getResource(String resourceName, int resourceType, String encoding )
-        throws ResourceNotFoundException, ParseErrorException, Exception;
+        throws ResourceNotFoundException, ParseErrorException;
 
     /**
-     *  Determines is a template exists, and returns name of the loader that 
+     *  Determines is a template exists, and returns name of the loader that
      *  provides it.  This is a slightly less hokey way to support
      *  the Velocity.templateExists() utility method, which was broken
      *  when per-template encoding was introduced.  We can revisit this.
@@ -75,7 +78,7 @@ public interface ResourceManager
      *  @return class name of loader than can provide it
      */
     public String getLoaderNameForResource(String resourceName );
-     
+
 }
 
 
