@@ -1,34 +1,39 @@
 package org.apache.velocity.runtime.resource.loader;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
- 
+
 import java.io.InputStream;
 
-import org.apache.velocity.runtime.resource.Resource;
-import org.apache.velocity.exception.ResourceNotFoundException;
-
 import org.apache.commons.collections.ExtendedProperties;
+import org.apache.commons.lang.StringUtils;
+import org.apache.velocity.exception.ResourceNotFoundException;
+import org.apache.velocity.runtime.resource.Resource;
+import org.apache.velocity.util.ClassUtils;
+import org.apache.velocity.util.ExceptionUtils;
 
 /**
  *  ClasspathResourceLoader is a simple loader that will load
  *  templates from the classpath.
  *  <br>
  *  <br>
- *  Will load templates from  from multiple instances of 
+ *  Will load templates from  from multiple instances of
  *  and arbitrary combinations of :
  *  <ul>
  *  <li> jar files
@@ -52,11 +57,11 @@ import org.apache.commons.collections.ExtendedProperties;
  *  <br>
  *  <br>
  *  This makes deployment trivial for web applications running in
- *  any Servlet 2.2 compliant servlet runner, such as Tomcat 3.2 
+ *  any Servlet 2.2 compliant servlet runner, such as Tomcat 3.2
  *  and others.
  *  <br>
  *  <br>
- *  For a Servlet Spec v2.2 servlet runner, 
+ *  For a Servlet Spec v2.2 servlet runner,
  *  just drop the jars of template files into the WEB-INF/lib
  *  directory of your webapp, and you won't have to worry about setting
  *  template paths or altering them with the root of the webapp
@@ -65,20 +70,24 @@ import org.apache.commons.collections.ExtendedProperties;
  *  <br>
  *  I have also tried it with a WAR deployment, and that seemed to
  *  work just fine.
- *  
+ *
+ * @author <a href="mailto:mailmur@yahoo.com">Aki Nieminen</a>
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
- * @version $Id: ClasspathResourceLoader.java,v 1.8.4.1 2004/03/03 23:23:02 geirm Exp $
+ * @version $Id: ClasspathResourceLoader.java 471259 2006-11-04 20:26:57Z henning $
  */
 public class ClasspathResourceLoader extends ResourceLoader
 {
 
     /**
      *  This is abstract in the base class, so we need it
+     * @param configuration
      */
     public void init( ExtendedProperties configuration)
     {
-        rsvc.info("ClasspathResourceLoader : initialization starting.");
-        rsvc.info("ClasspathResourceLoader : initialization complete.");
+        if (log.isTraceEnabled())
+        {
+            log.trace("ClasspathResourceLoader : initialization complete.");
+        }
     }
 
     /**
@@ -90,35 +99,43 @@ public class ClasspathResourceLoader extends ResourceLoader
      * @throws ResourceNotFoundException if template not found
      *         in  classpath.
      */
-    public synchronized InputStream getResourceStream( String name )
+    public InputStream getResourceStream( String name )
         throws ResourceNotFoundException
     {
         InputStream result = null;
-        
-        if (name == null || name.length() == 0)
+
+        if (StringUtils.isEmpty(name))
         {
             throw new ResourceNotFoundException ("No template name provided");
         }
-        
-        try 
+
+        /**
+         * look for resource in thread classloader first (e.g. WEB-INF\lib in
+         * a servlet container) then fall back to the system classloader.
+         */
+
+        try
         {
-            ClassLoader classLoader = this.getClass().getClassLoader();
-            result= classLoader.getResourceAsStream( name );
+            result = ClassUtils.getResourceAsStream( getClass(), name );
         }
         catch( Exception fnfe )
         {
-            /*
-             *  log and convert to a general Velocity ResourceNotFoundException
-             */
-            
-            throw new ResourceNotFoundException( fnfe.getMessage() );
+            throw (ResourceNotFoundException) ExceptionUtils.createWithCause(ResourceNotFoundException.class, "problem with template: " + name, fnfe );
         }
-        
+
+        if (result == null)
+        {
+             String msg = "ClasspathResourceLoader Error: cannot find resource " +
+              name;
+
+             throw new ResourceNotFoundException( msg );
+        }
+
         return result;
     }
-    
+
     /**
-     * Defaults to return false.
+     * @see org.apache.velocity.runtime.resource.loader.ResourceLoader#isSourceModified(org.apache.velocity.runtime.resource.Resource)
      */
     public boolean isSourceModified(Resource resource)
     {
@@ -126,7 +143,7 @@ public class ClasspathResourceLoader extends ResourceLoader
     }
 
     /**
-     * Defaults to return 0
+     * @see org.apache.velocity.runtime.resource.loader.ResourceLoader#getLastModified(org.apache.velocity.runtime.resource.Resource)
      */
     public long getLastModified(Resource resource)
     {
