@@ -52,7 +52,6 @@ import org.apache.velocity.runtime.parser.node.ASTObjectArray;
 import org.apache.velocity.runtime.parser.node.ASTOrNode;
 import org.apache.velocity.runtime.parser.node.ASTReference;
 import org.apache.velocity.runtime.parser.node.ASTSetDirective;
-import org.apache.velocity.runtime.parser.node.ASTStop;
 import org.apache.velocity.runtime.parser.node.ASTStringLiteral;
 import org.apache.velocity.runtime.parser.node.ASTSubtractNode;
 import org.apache.velocity.runtime.parser.node.ASTText;
@@ -71,7 +70,7 @@ import org.apache.velocity.runtime.parser.node.SimpleNode;
  * as well.
  *
  * @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
- * @version $Id: NodeViewMode.java 685685 2008-08-13 21:43:27Z nbubna $
+ * @version $Id: NodeViewMode.java 747106 2009-02-23 19:25:14Z nbubna $
  */
 public class NodeViewMode extends BaseVisitor
 {
@@ -433,13 +432,4 @@ public class NodeViewMode extends BaseVisitor
     {
         return showNode(node,data);
     }
-
-    /**
-     * @see org.apache.velocity.runtime.visitor.BaseVisitor#visit(org.apache.velocity.runtime.parser.node.ASTStop, java.lang.Object)
-     * @since 1.5
-     */
-    public Object visit(ASTStop node, Object data)
-    {
-        return showNode(node,data);
-    }
 }
