@@ -1,26 +1,29 @@
 package org.apache.velocity.texen.util;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
 import java.io.FileInputStream;
 import java.io.InputStream;
-import java.io.IOException;
 import java.util.Properties;
 import java.util.StringTokenizer;
+
 import org.apache.velocity.texen.Generator;
 
 /**
@@ -29,7 +32,7 @@ import org.apache.velocity.texen.Generator;
  *
  * @author <a href="mailto:leon@opticode.co.za">Leon Messerschmidt</a>
  * @author <a href="mailto:sbailliez@apache.org">Stephane Bailliez</a>
- * @version $Id: PropertiesUtil.java,v 1.9.8.1 2004/03/03 23:23:07 geirm Exp $ 
+ * @version $Id: PropertiesUtil.java 510628 2007-02-22 19:07:59Z nbubna $
  */
 public class PropertiesUtil
 {
@@ -42,23 +45,34 @@ public class PropertiesUtil
      * @return a properties instance filled with the properties found
      * in the file or an empty instance if no file was found.
      */
-    public Properties load(String propertiesFile)
+    public Properties load(final String propertiesFile)
     {
-        Properties properties = new Properties();
+        Properties properties = null;
+
         String templatePath = Generator.getInstance().getTemplatePath();
-        if (templatePath != null)
+        try
         {
-            properties = loadFromTemplatePath(propertiesFile);
+            if (templatePath != null)
+            {
+                properties = loadFromTemplatePath(propertiesFile);
+            }
+            else
+            {
+                properties = loadFromClassPath(propertiesFile);
+            }
         }
-        else
+        catch (RuntimeException e)
         {
-            properties = loadFromClassPath(propertiesFile);
+            throw e;
         }
-    
+        catch (Exception e)
+        {
+            throw new RuntimeException("Could not load properties: " + e.getMessage());
+        }
+
         return properties;
-        
     }
-    
+
     /**
      * Load a properties file from the templatePath defined in the
      * generator. As the templatePath can contains multiple paths,
@@ -71,12 +85,14 @@ public class PropertiesUtil
      * a relative pathname.
      * @return a properties instance loaded with the properties from
      * the file. If no file can be found it returns an empty instance.
+     * @throws Exception
      */
-    protected Properties loadFromTemplatePath(String propertiesFile)
+    protected Properties loadFromTemplatePath(final String propertiesFile)
+    	throws Exception
     {
         Properties properties = new Properties();
         String templatePath = Generator.getInstance().getTemplatePath();
-        
+
         // We might have something like the following:
         //
         // #set ($dbprops = $properties.load("$generator.templatePath/path/props")
@@ -93,6 +109,7 @@ public class PropertiesUtil
         while (st.hasMoreTokens())
         {
             String templateDir = st.nextToken();
+            InputStream stream = null;
             try
             {
                 // If the properties file is being pulled from the
@@ -101,13 +118,13 @@ public class PropertiesUtil
                 // path and they are simply using:
                 //
                 // #set ($dbprops = $properties.load("props") (1)
-                // 
+                //
                 // than we have to tack on the templatePath in order
                 // for the properties file to be found. We want (1)
                 // to work whether the generation is being run from
                 // the file system or from a JAR file.
                 String fullPath = propertiesFile;
-                
+
                 // FIXME probably not that clever since there could be
                 // a mix of file separators and the test will fail :-(
                 if (!fullPath.startsWith(templateDir))
@@ -115,31 +132,39 @@ public class PropertiesUtil
                     fullPath = templateDir + "/" + propertiesFile;
                 }
 
-                properties.load(new FileInputStream(fullPath));
+                stream = new FileInputStream(fullPath);
+                properties.load(stream);
                 // first pick wins, we don't need to go further since
                 // we found a valid file.
                 break;
             }
-            catch (Exception e)
+            finally
             {
-                // do nothing
+        	if (stream != null)
+        	{
+        	    stream.close();
+        	}
             }
-        } 
+        }
         return properties;
     }
 
     /**
      * Load a properties file from the classpath
      *
-     * @param propertiesFile the properties file to load.
+     * @param propertiesName the properties file to load.
      * @return a properties instance loaded with the properties from
      * the file. If no file can be found it returns an empty instance.
-     */ 
-    protected Properties loadFromClassPath(String propertiesFile)
+     * @throws Exception
+     */
+    protected Properties loadFromClassPath(final String propertiesName)
+    	throws Exception
     {
         Properties properties = new Properties();
         ClassLoader classLoader = this.getClass().getClassLoader();
-        
+
+        InputStream inputStream = null;
+
         try
         {
             // This is a hack for now to make sure that properties
@@ -149,18 +174,20 @@ public class PropertiesUtil
             // and this hack will allow those same templates
             // that use $generator.templatePath to work in
             // JAR files.
-            if (propertiesFile.startsWith("$generator"))
-            {
-                propertiesFile = propertiesFile.substring(
-                    "$generator.templatePath/".length());
-            }
-            
-            InputStream inputStream = classLoader.getResourceAsStream(propertiesFile);
+
+            String propertiesFile = propertiesName.startsWith("$generator")
+        	    ? propertiesName.substring("$generator.templatePath/".length())
+    		    : propertiesName;
+
+    	    inputStream = classLoader.getResourceAsStream(propertiesFile);
             properties.load(inputStream);
         }
-        catch (IOException ioe)
+        finally
         {
-            // do nothing
+            if (inputStream != null)
+            {
+        	inputStream.close();
+            }
         }
         return properties;
     }
