@@ -1,33 +1,33 @@
 package org.apache.velocity.util;
 
 /*
- * Copyright 2001,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
- * 
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
  */
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileReader;
-import java.io.ByteArrayOutputStream;
 import java.io.PrintWriter;
-
-import java.net.MalformedURLException;
-
 import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.List;
-import java.util.StringTokenizer;
 import java.util.Map;
+import java.util.StringTokenizer;
 
 
 /**
@@ -39,7 +39,7 @@ import java.util.Map;
  *
  *  @author <a href="mailto:jvanzyl@apache.org">Jason van Zyl</a>
  *  @author <a href="mailto:dlr@finemaltcoding.com">Daniel Rall</a>
- *  @version $Id: StringUtils.java,v 1.16.8.1 2004/03/03 23:23:07 geirm Exp $
+ *  @version $Id: StringUtils.java 685685 2008-08-13 21:43:27Z nbubna $
  */
 public class StringUtils
 {
@@ -47,11 +47,6 @@ public class StringUtils
      * Line separator for the OS we are operating on.
      */
     private static final String EOL = System.getProperty("line.separator");
-    
-    /**
-     * Length of the line separator.
-     */
-    private static final int EOL_LENGTH = EOL.length();
 
     /**
      * Concatenates a list of objects as a String.
@@ -74,7 +69,7 @@ public class StringUtils
     /**
      * Return a package name as a relative path name
      *
-     * @param String package name to convert to a directory.
+     * @param pckge package name to convert to a directory.
      * @return String directory path.
      */
     static public String getPackageAsPath(String pckge)
@@ -85,16 +80,16 @@ public class StringUtils
     /**
      * <p>
      * Remove underscores from a string and replaces first
-     * letters with capitals.  Other letters are changed to lower case. 
+     * letters with capitals.  Other letters are changed to lower case.
      * </p>
      *
-     * <p> 
+     * <p>
      * For example <code>foo_bar</code> becomes <code>FooBar</code>
      * but <code>foo_barBar</code> becomes <code>FooBarbar</code>.
      * </p>
      *
      * @param data string to remove underscores from.
-     * @return String 
+     * @return String
      * @deprecated Use the org.apache.commons.util.StringUtils class
      * instead.  Using its firstLetterCaps() method in conjunction
      * with a StringTokenizer will achieve the same result.
@@ -106,7 +101,7 @@ public class StringUtils
         temp = data;
 
         StringTokenizer st = new StringTokenizer(temp, "_");
-       
+
         while (st.hasMoreTokens())
         {
             String element = (String) st.nextElement();
@@ -117,21 +112,21 @@ public class StringUtils
     }
 
     /**
-     * <p> 
+     * <p>
      *  'Camels Hump' replacement of underscores.
      * </p>
      *
-     * <p> 
+     * <p>
      * Remove underscores from a string but leave the capitalization of the
      * other letters unchanged.
      * </p>
      *
-     * <p> 
+     * <p>
      * For example <code>foo_barBar</code> becomes <code>FooBarBar</code>.
      * </p>
      *
      * @param data string to hump
-     * @return String 
+     * @return String
      */
     static public String removeAndHump (String data)
     {
@@ -143,7 +138,7 @@ public class StringUtils
      * 'Camels Hump' replacement.
      * </p>
      *
-     * <p> 
+     * <p>
      * Remove one string from another string but leave the capitalization of the
      * other letters unchanged.
      * </p>
@@ -154,7 +149,7 @@ public class StringUtils
      *
      * @param data string to hump
      * @param replaceThis string to be replaced
-     * @return String 
+     * @return String
      */
     static public String removeAndHump (String data,String replaceThis)
     {
@@ -163,22 +158,22 @@ public class StringUtils
         temp = data;
 
         StringTokenizer st = new StringTokenizer(temp, replaceThis);
-       
+
         while (st.hasMoreTokens())
         {
             String element = (String) st.nextElement();
             out.append ( capitalizeFirstLetter(element));
         }//while
-        
+
         return out.toString();
     }
 
     /**
-     * <p> 
+     * <p>
      *  Makes the first letter caps and the rest lowercase.
      * </p>
      *
-     * <p> 
+     * <p>
      *  For example <code>fooBar</code> becomes <code>Foobar</code>.
      * </p>
      *
@@ -193,11 +188,11 @@ public class StringUtils
     }
 
     /**
-     * <p> 
-     * Capitalize the first letter but leave the rest as they are. 
+     * <p>
+     * Capitalize the first letter but leave the rest as they are.
      * </p>
      *
-     * <p> 
+     * <p>
      *  For example <code>fooBar</code> becomes <code>FooBar</code>.
      * </p>
      *
@@ -231,11 +226,11 @@ public class StringUtils
 
     /**
      * Chop i characters off the end of a string.
-     * This method assumes that any EOL characters in String s 
+     * This method assumes that any EOL characters in String s
      * and the platform EOL will be the same.
-     * A 2 character EOL will count as 1 character. 
+     * A 2 character EOL will count as 1 character.
      *
-     * @param string String to chop.
+     * @param s String to chop.
      * @param i Number of characters to chop.
      * @return String with processed answer.
      */
@@ -245,10 +240,10 @@ public class StringUtils
     }
 
     /**
-     * Chop i characters off the end of a string. 
-     * A 2 character EOL will count as 1 character. 
+     * Chop i characters off the end of a string.
+     * A 2 character EOL will count as 1 character.
      *
-     * @param string String to chop.
+     * @param s String to chop.
      * @param i Number of characters to chop.
      * @param eol A String representing the EOL (end of line).
      * @return String with processed answer.
@@ -285,6 +280,11 @@ public class StringUtils
         return s.substring( 0, length);
     }
 
+    /**
+     * @param argStr
+     * @param vars
+     * @return Substituted String.
+     */
     public static StringBuffer stringSubstitution( String argStr,
                                                    Hashtable vars )
     {
@@ -297,8 +297,8 @@ public class StringUtils
      * string with the value of provided by the key "variable"
      * in the provided hashtable.
      *
-     * @param String target string
-     * @param Hashtable name/value pairs used for substitution
+     * @param argStr target string
+     * @param vars name/value pairs used for substitution
      * @return String target string with replacements.
      */
     public static StringBuffer stringSubstitution(String argStr,
@@ -344,43 +344,57 @@ public class StringUtils
 
         return argBuf;
     }
-    
+
     /**
      * Read the contents of a file and place them in
      * a string object.
      *
-     * @param String path to file.
+     * @param file path to file.
      * @return String contents of the file.
      */
     public static String fileContentsToString(String file)
     {
         String contents = "";
-        
-        File f = new File(file);
-        
-        if (f.exists())
+
+        File f = null;
+        try
         {
-            try
+            f = new File(file);
+
+            if (f.exists())
             {
-                FileReader fr = new FileReader(f);
-                char[] template = new char[(int) f.length()];
-                fr.read(template);
-                contents = new String(template);
-            }
-            catch (Exception e)
-            {
-                System.out.println(e);
-                e.printStackTrace();
+                FileReader fr = null;
+                try
+                {
+                    fr = new FileReader(f);
+                    char[] template = new char[(int) f.length()];
+                    fr.read(template);
+                    contents = new String(template);
+                }
+                catch (Exception e)
+                {
+                    e.printStackTrace();
+                }
+                finally
+                {
+                    if (fr != null)
+                    {
+                        fr.close();
+                    }
+                }
             }
         }
-        
+        catch (Exception e)
+        {
+            e.printStackTrace();
+        }
         return contents;
     }
-    
+
     /**
      * Remove/collapse multiple newline characters.
      *
-     * @param String string to collapse newlines in.
+     * @param argStr string to collapse newlines in.
      * @return String
      */
     public static String collapseNewlines(String argStr)
@@ -404,7 +418,7 @@ public class StringUtils
     /**
      * Remove/collapse multiple spaces.
      *
-     * @param String string to remove multiple spaces from.
+     * @param argStr string to remove multiple spaces from.
      * @return String
      */
     public static String collapseSpaces(String argStr)
@@ -429,9 +443,9 @@ public class StringUtils
       * Replaces all instances of oldString with newString in line.
       * Taken from the Jive forum package.
       *
-      * @param String original string.
-      * @param String string in line to replace.
-      * @param String replace oldString with this.
+      * @param line original string.
+      * @param oldString string in line to replace.
+      * @param newString replace oldString with this.
       * @return String string with replacements.
       */
     public static final String sub(String line, String oldString,
@@ -458,7 +472,7 @@ public class StringUtils
         }
         return line;
     }
-    
+
     /**
      * Returns the output of printStackTrace as a String.
      *
@@ -505,7 +519,7 @@ public class StringUtils
         {
             normalized = "/" + normalized;
         }
-        
+
         // Resolve occurrences of "//" in the normalized path
         while (true)
         {
@@ -557,21 +571,22 @@ public class StringUtils
      * If state is true then return the trueString, else
      * return the falseString.
      *
-     * @param boolean 
-     * @param String trueString
-     * @param String falseString
+     * @param state
+     * @param trueString
+     * @param falseString
+     * @return Selected result.
      */
     public String select(boolean state, String trueString, String falseString)
     {
         if (state)
         {
             return trueString;
-        }            
+        }
         else
         {
             return falseString;
-        }            
-    }            
+        }
+    }
 
     /**
      * Check to see if all the string objects passed
@@ -583,14 +598,49 @@ public class StringUtils
     public boolean allEmpty(List list)
     {
         int size = list.size();
-        
+
         for (int i = 0; i < size; i++)
         {
             if (list.get(i) != null && list.get(i).toString().length() > 0)
             {
                 return false;
             }
-        }            
+        }
         return true;
     }
+
+    /**
+     * Trim all strings in a List.  Changes the strings in the existing list.
+     * @param list
+     * @return List of trimmed strings.
+     * @since 1.5
+     */
+    public static List trimStrings(List list)
+    {
+        if (list == null)
+            return null;
+
+        int sz = list.size();
+        for (int i = 0; i < sz; i++)
+            list.set(i,nullTrim((String) list.get(i)));
+        return list;
+    }
+
+    /**
+     * Trim the string, but pass a null through.
+     * @param s
+     * @return List of trimmed Strings.
+     * @since 1.5
+     */
+    public static String nullTrim(String s)
+    {
+        if (s == null)
+        {
+            return null;
+        }
+        else
+        {
+            return s.trim();
+        }
+    }
 }
