@@ -21,11 +21,10 @@ package org.apache.velocity.util.introspection;
 
 import java.lang.reflect.Method;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.Iterator;
-import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
+
 import org.apache.velocity.util.MapFactory;
 
 /**
@@ -35,7 +34,7 @@ import org.apache.velocity.util.MapFactory;
  * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph Reck</a>
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
  * @author <a href="mailto:szegedia@freemail.hu">Attila Szegedi</a>
- * @version $Id: MethodMap.java 891385 2009-12-16 19:06:18Z nbubna $
+ * @version $Id: MethodMap.java 935975 2010-04-20 16:04:55Z nbubna $
  */
 public class MethodMap
 {
@@ -210,6 +209,7 @@ public class MethodMap
                 
         if (equivalentMatches != null)
         {
+            //System.out.println("ambiguous: "+equivalentMatches);//for debugging only
             throw new AmbiguousException();
         }
         return bestMatch;
@@ -261,10 +261,12 @@ public class MethodMap
                 boolean last = (i == c1.length - 1);
                 c1MoreSpecific =
                     c1MoreSpecific ||
-                    isStrictConvertible(c2[i], c1[i], last);
+                    isStrictConvertible(c2[i], c1[i], last) ||
+                    c2[i] == Object.class;//Object is always least-specific
                 c2MoreSpecific =
                     c2MoreSpecific ||
-                    isStrictConvertible(c1[i], c2[i], last);
+                    isStrictConvertible(c1[i], c2[i], last) ||
+                    c1[i] == Object.class;//Object is always least-specific
             }
         }
 
