@@ -26,22 +26,20 @@ import java.util.Iterator;
  *  behavior in Velocity to be customized.
  *
  * @author <a href="mailto:geirm@apache.org">Geir Magusson Jr.</a>
- * @version $Id: Uberspect.java 463298 2006-10-12 16:10:32Z henning $
+ * @version $Id: Uberspect.java 774412 2009-05-13 15:54:07Z nbubna $
  */
 public interface Uberspect
 {
     /**
      *  Initializer - will be called before use
-     * @throws Exception
      */
-    public void init() throws Exception;
+    public void init();
 
     /**
      *  To support iteratives - #foreach()
      * @param obj
      * @param info
      * @return An Iterator.
-     * @throws Exception
      */
     public Iterator getIterator(Object obj, Info info) throws Exception;
 
@@ -52,7 +50,6 @@ public interface Uberspect
      * @param args
      * @param info
      * @return A Velocity Method.
-     * @throws Exception
      */
     public VelMethod getMethod(Object obj, String method, Object[] args, Info info) throws Exception;
 
@@ -62,7 +59,6 @@ public interface Uberspect
      * @param identifier
      * @param info
      * @return A Velocity Getter.
-     * @throws Exception
      */
     public VelPropertyGet getPropertyGet(Object obj, String identifier, Info info) throws Exception;
 
@@ -73,7 +69,6 @@ public interface Uberspect
      * @param arg
      * @param info
      * @return A Velocity Setter.
-     * @throws Exception
      */
     public VelPropertySet getPropertySet(Object obj, String identifier, Object arg, Info info) throws Exception;
 }
