@@ -26,6 +26,7 @@ import java.util.Enumeration;
 import java.util.Iterator;
 import java.util.Map;
 
+import org.apache.velocity.exception.VelocityException;
 import org.apache.velocity.runtime.RuntimeLogger;
 import org.apache.velocity.runtime.log.Log;
 import org.apache.velocity.runtime.log.RuntimeLoggerLog;
@@ -48,7 +49,7 @@ import org.apache.velocity.util.EnumerationIterator;
  *
  * @author <a href="mailto:geirm@optonline.net">Geir Magnusson Jr.</a>
  * @author <a href="mailto:henning@apache.org">Henning P. Schmiedehausen</a>
- * @version $Id: UberspectImpl.java 723123 2008-12-03 23:14:34Z nbubna $
+ * @version $Id: UberspectImpl.java 898032 2010-01-11 19:51:03Z nbubna $
  */
 public class UberspectImpl implements Uberspect, UberspectLoggable
 {
@@ -67,7 +68,7 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
      *  makes sure that the log gets set before this is called,
      *  we can initialize the Introspector using the log object.
      */
-    public void init() throws Exception
+    public void init()
     {
         introspector = new Introspector(log);
     }
@@ -102,10 +103,9 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
      * @param obj The iterative object.
      * @param i Info about the object's location.
      * @return An {@link Iterator} object.
-     * @throws Exception
      */
     public Iterator getIterator(Object obj, Info i)
-            throws Exception
+        throws Exception
     {
         if (obj.getClass().isArray())
         {
@@ -153,7 +153,15 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
                 Class returns = iter.getReturnType();
                 if (Iterator.class.isAssignableFrom(returns))
                 {
-                    return (Iterator)iter.invoke(obj, null);
+                    try
+                    {
+                        return (Iterator)iter.invoke(obj, null);
+                    } 
+                    catch (Exception e)
+                    {
+                        throw new VelocityException("Error invoking the method 'iterator' on class '" 
+                            + obj.getClass().getName() +"'", e);
+                    }
                 }
                 else
                 {
@@ -180,10 +188,9 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
      * @param args
      * @param i
      * @return A Velocity Method.
-     * @throws Exception
      */
     public VelMethod getMethod(Object obj, String methodName, Object[] args, Info i)
-            throws Exception
+        throws Exception
     {
         if (obj == null)
         {
@@ -230,7 +237,7 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
      * @throws Exception
      */
     public VelPropertyGet getPropertyGet(Object obj, String identifier, Info i)
-            throws Exception
+        throws Exception
     {
         if (obj == null)
         {
@@ -285,8 +292,7 @@ public class UberspectImpl implements Uberspect, UberspectLoggable
      * @throws Exception
      */
     public VelPropertySet getPropertySet(Object obj, String identifier,
-                                         Object arg, Info i)
-            throws Exception
+                                         Object arg, Info i) throws Exception
     {
         if (obj == null)
         {
