@@ -19,13 +19,12 @@ package org.apache.velocity.test.issues;
  * under the License.    
  */
 
-import org.apache.velocity.test.BaseEvalTestCase;
-import org.apache.velocity.runtime.RuntimeConstants;
+import org.apache.velocity.test.BaseTestCase;
 
 /**
  * This class tests VELOCITY-631.
  */
-public class Velocity631TestCase extends BaseEvalTestCase
+public class Velocity631TestCase extends BaseTestCase
 {
     public Velocity631TestCase(String name)
     {
