@@ -19,12 +19,12 @@ package org.apache.velocity.test.issues;
  * under the License.    
  */
 
-import org.apache.velocity.test.BaseEvalTestCase;
+import org.apache.velocity.test.BaseTestCase;
 
 /**
  * This class tests VELOCITY-701.
  */
-public class Velocity701TestCase extends BaseEvalTestCase
+public class Velocity701TestCase extends BaseTestCase
 {
     public Velocity701TestCase(String name)
     {
@@ -48,4 +48,24 @@ public class Velocity701TestCase extends BaseEvalTestCase
     
     }
 
+    /* TODO: uncomment for jdk 1.5+
+    public void testEnum()
+    {
+        context.put("bar", Bar.ONE);
+        assertEvalEquals("foo", "$bar.foo");
+    }
+
+    public static enum Bar {
+
+        ONE(){
+            public String getFoo() {
+                return "foo";
+            }
+        };
+
+       //This was an abstract method, but Velocity 1.6 quit working with it.
+       public abstract String getFoo();
+
+    }*/
+
 }
